pub struct Layered<L, H, T, S> { /* private fields */ }Expand description
A handler wrapped with a Tower layer for middleware.
This type is returned by Handler::layer and implements Handler
itself, allowing you to compose multiple layers or pass it to
[Router::route].